==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkModifiedBSPTree.java <==
// java wrapper for vtkModifiedBSPTree object
//

package vtk;
import vtk.*;

public class vtkModifiedBSPTree extends vtkAbstractCellLocator
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void FreeSearchStructure_2();
  public void FreeSearchStructure()
    { FreeSearchStructure_2(); }

  private native void BuildLocator_3();
  public void BuildLocator()
    { BuildLocator_3(); }

  private native void GenerateRepresentation_4(int id0,vtkPolyData id1);
  public void GenerateRepresentation(int id0,vtkPolyData id1)
    { GenerateRepresentation_4(id0,id1); }

  private native void GenerateRepresentationLeafs_5(vtkPolyData id0);
  public void GenerateRepresentationLeafs(vtkPolyData id0)
    { GenerateRepresentationLeafs_5(id0); }

  private native int IntersectWithLine_6(double id0[],double id1[],double id2,vtkPoints id3,vtkIdList id4);
  public int IntersectWithLine(double id0[],double id1[],double id2,vtkPoints id3,vtkIdList id4)
    { return IntersectWithLine_6(id0,id1,id2,id3,id4); }

  private native boolean InsideCellBounds_7(double id0[],int id1);
  public boolean InsideCellBounds(double id0[],int id1)
    { return InsideCellBounds_7(id0,id1); }

  private native long GetLeafNodeCellInformation_8();
  public vtkIdListCollection GetLeafNodeCellInformation() {
    long temp = GetLeafNodeCellInformation_8();

    if (temp == 0) return null;
    return (vtkIdListCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int IntersectWithLine_9(double id0[],double id1[],vtkPoints id2,vtkIdList id3);
  public int IntersectWithLine(double id0[],double id1[],vtkPoints id2,vtkIdList id3)
    { return IntersectWithLine_9(id0,id1,id2,id3); }

  private native int FindCell_10(double id0[]);
  public int FindCell(double id0[])
    { return FindCell_10(id0); }

  public vtkModifiedBSPTree() { super(); }

  public vtkModifiedBSPTree(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkModifiedBSPTree.java <==
// java wrapper for vtkModifiedBSPTree object
//

package vtk;
import vtk.*;

public class vtkModifiedBSPTree extends vtkAbstractCellLocator
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void FreeSearchStructure_2();
  public void FreeSearchStructure()
    { FreeSearchStructure_2(); }

  private native void BuildLocator_3();
  public void BuildLocator()
    { BuildLocator_3(); }

  private native void GenerateRepresentation_4(int id0,vtkPolyData id1);
  public void GenerateRepresentation(int id0,vtkPolyData id1)
    { GenerateRepresentation_4(id0,id1); }

  private native void GenerateRepresentationLeafs_5(vtkPolyData id0);
  public void GenerateRepresentationLeafs(vtkPolyData id0)
    { GenerateRepresentationLeafs_5(id0); }

  private native int IntersectWithLine_6(double id0[],double id1[],double id2,vtkPoints id3,vtkIdList id4);
  public int IntersectWithLine(double id0[],double id1[],double id2,vtkPoints id3,vtkIdList id4)
    { return IntersectWithLine_6(id0,id1,id2,id3,id4); }

  private native boolean InsideCellBounds_7(double id0[],int id1);
  public boolean InsideCellBounds(double id0[],int id1)
    { return InsideCellBounds_7(id0,id1); }

  private native long GetLeafNodeCellInformation_8();
  public vtkIdListCollection GetLeafNodeCellInformation() {
    long temp = GetLeafNodeCellInformation_8();

    if (temp == 0) return null;
    return (vtkIdListCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int IntersectWithLine_9(double id0[],double id1[],vtkPoints id2,vtkIdList id3);
  public int IntersectWithLine(double id0[],double id1[],vtkPoints id2,vtkIdList id3)
    { return IntersectWithLine_9(id0,id1,id2,id3); }

  private native int FindCell_10(double id0[]);
  public int FindCell(double id0[])
    { return FindCell_10(id0); }

  public vtkModifiedBSPTree() { super(); }

  public vtkModifiedBSPTree(long id) { super(id); }
  public native long   VTKInit();

}
